@@ -59,7 +59,16 @@
 #'   value of \code{NA} to indicate that the test should be terminated. However, see the arguments for
 #'   further returned object descriptions
 #'
-#' @references
+#' @references 
+#' 
+#' Chalmers, R., P. (2012). mirt: A Multidimensional Item Response Theory
+#' Package for the R Environment. \emph{Journal of Statistical Software, 48}(6), 1-29.
+#' \doi{10.18637/jss.v048.i06}
+#' 
+#' Chalmers, R. P. (2016). Generating Adaptive and Non-Adaptive Test Interfaces for 
+#' Multidimensional Item Response Theory Applications. \emph{Journal of Statistical Software, 71}(5), 
+#' 1-39. \doi{10.18637/jss.v071.i05}
+#'
 #' van der Linden, W. J. (2005). Linear models for optimal test design. Springer.
 #'
 #' @examples
@@ -194,6 +203,7 @@ findNextCATItem <- function(person, test, design, subset = NULL, start = TRUE,
         if(criteria %in% c('seq', 'random'))
             stop('criteria makes no sense with values=TRUE', call.=FALSE)
         which_not_answered <- 1L:test@length
+        which_not_answered <- which_not_answered[which_not_answered %in% subset]
         not_answered <- rep(TRUE, length(not_answered))
     }
     if(criteria %in% c('MEI', 'MEPV', 'IKL', 'IKLP', 'IKLn', 'IKLPn')){
@@ -279,18 +289,23 @@ findNextCATItem <- function(person, test, design, subset = NULL, start = TRUE,
         MLWI(which_not_answered=which_not_answered, person=person, test=test, thetas=thetas,
              prior=TRUE)
     } else if(criteria == 'Drule' || criteria == 'DPrule'){
-        Drule(which_not_answered=which_not_answered, person=person, test=test, thetas=thetas)
+        Drule(which_not_answered=which_not_answered, person=person, test=test, thetas=thetas,
+              prior = criteria == 'DPrule')
     } else if(criteria == 'Erule' || criteria == 'EPrule'){
-        Erule(which_not_answered=which_not_answered, person=person, test=test, thetas=thetas)
+        Erule(which_not_answered=which_not_answered, person=person, test=test, thetas=thetas,
+              prior = criteria == 'EPrule')
     } else if(criteria == 'Trule' || criteria == 'TPrule'){
         Trule(which_not_answered=which_not_answered, person=person, test=test,
-              design=design, thetas=thetas)
+              design=design, thetas=thetas,
+              prior = criteria == 'TPrule')
     } else if(criteria == 'Arule' || criteria == 'APrule'){
         -Arule(which_not_answered=which_not_answered,
-               person=person, test=test, design=design, thetas=thetas)
+               person=person, test=test, design=design, thetas=thetas,
+               prior = criteria == 'APrule')
     } else if(criteria == 'Wrule' || criteria == 'WPrule'){
         Wrule(which_not_answered=which_not_answered, person=person, test=test,
-              design=design, thetas=thetas)
+              design=design, thetas=thetas,
+              prior = criteria == 'WPrule')
     } else if(criteria == 'info_mats'){
         InfoMats(which_not_answered=which_not_answered, person=person, test=test, thetas=thetas)
     } else {
